import { Typography, List, ListItem, Stack, Divider, Box } from '@mui/material';
import { green, red, orange } from '@mui/material/colors';
import { useAppContext } from '../Contexts/AppContext';
import { ArrowCircleLeft, Check, Clear } from '@mui/icons-material/';

const CompletedQuiz = () => {
  const { quiz } = useAppContext();
  const equalsIgnoreOrder = (a, b) => {
    if (a.length !== b.length) return false;
    const uniqueValues = new Set([...a, ...b]);
    for (const v of uniqueValues) {
      const aCount = a.filter((e) => e === v).length;
      const bCount = b.filter((e) => e === v).length;
      if (aCount !== bCount) return false;
    }
    return true;
  };

  if (!quiz) return;

  const markedQuiz = quiz.reduce(
    (a, b) => {
      const checkAns = equalsIgnoreOrder(b.answers, b.userAns);
      const result = {
        totalQs: a.totalQs + 1,
        correct: checkAns ? a.correct + 1 : a.correct,
        incorrect: !checkAns ? a.incorrect + 1 : a.incorrect,
        correctPercent: checkAns
          ? Math.round(((a.correct + 1) / (a.totalQs + 1)) * 100)
          : Math.round((a.correct / (a.totalQs + 1)) * 100),
        incorrectPercent: !checkAns
          ? Math.round(((a.incorrect + 1) / (a.totalQs + 1)) * 100)
          : Math.round((a.incorrect / (a.totalQs + 1)) * 100),
      };

      return quiz.length !== a.totalQs + 1
        ? {
            checkedTest: false,
            ...result,
          }
        : {
            ...result,
            checkedTest: true,
          };
    },
    {
      checkedTest: false,
      totalQs: 0,
      incorrect: 0,
      correct: 0,
      correctPercent: 0,
      incorrectPercent: 0,
    }
  );

  return (
    <Stack sx={{ mx: 2 }}>
      <Typography variant="h4">Quiz Results</Typography>
      <Divider />
      <Typography paddingY={1} align="center" variant="subtitle1">
        you scored {markedQuiz.correctPercent}%
        <br />
        results: {markedQuiz.correct} / {markedQuiz.totalQs}
      </Typography>
      <List>
        {quiz.map(({ id, question, options, userAns, answers }, index) => (
          <div key={id}>
            <ListItem disableGutters divider>
              {index + 1 + ') '}
              {question}
            </ListItem>
            {options.map((opt) => (
              <div key={id + opt}>
                <ListItem
                  sx={{
                    my: 0.5,
                    backgroundColor:
                      userAns.includes(opt) && answers.includes(opt)
                        ? green[400] // good job
                        : userAns.includes(opt) && !answers.includes(opt)
                        ? red[400] // bad job
                        : answers.includes(opt)
                        ? orange[400] // better luck next time
                        : null,
                  }}
                >
                  {opt}
                  {userAns.includes(opt) && answers.includes(opt) ? (
                    <>
                      <Box sx={{ flexGrow: 1 }} />
                      <Check />
                    </>
                  ) : userAns.includes(opt) && !answers.includes(opt) ? (
                    <>
                      <Box sx={{ flexGrow: 1 }} />
                      <Clear />
                    </>
                  ) : answers.includes(opt) ? (
                    <>
                      <Box sx={{ flexGrow: 1 }} />
                      <ArrowCircleLeft /> pick me!
                    </>
                  ) : null}
                </ListItem>
              </div>
            ))}
          </div>
        ))}
      </List>
    </Stack>
  );
};

export default CompletedQuiz;
