import { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import {
  Box,
  Typography,
  Toolbar,
  IconButton,
  Button,
  Chip,
  styled,
  Tooltip,
} from '@mui/material';
import { Quiz as QuizIcon, Info as InfoIcon } from '@mui/icons-material';
import AccountCircle from '@mui/icons-material/AccountCircle';
import MuiAppBar from '@mui/material/AppBar';
import { UserProfile } from './UserProfile';
import { CONSTS } from '../Constants';
import { useAppContext } from '../Contexts/AppContext';

const Nav = () => {
  const { currentQuiz, resetQuiz, activeStep, maxSteps, quizModified } =
    useAppContext();
  const navigate = useNavigate();
  const [showProfile, setShowProfile] = useState(false);

  const toggleProfile = () => (event) => {
    if (
      event.type === 'keydown' &&
      (event.key === 'Tab' || event.key === 'Shift')
    ) {
      return;
    }
    setShowProfile((showProfile) => !showProfile);
  };

  const AppBar = styled(MuiAppBar, {
    shouldForwardProp: (prop) => prop,
  })(({ theme }) => ({ ...theme.mixins.denseToolbar }));

  const handleDelete = () => {
    resetQuiz();
    navigate('/');
  };

  return (
    <>
      <AppBar position="static">
        <Toolbar disableGutters variant="dense" sx={{ mx: 1 }}>
          <Button variant="text" onClick={() => navigate(`/`)}>
            <QuizIcon sx={{ mr: 1, color: '#fff' }} />
            <Typography
              variant="subtitle2"
              component="div"
              sx={{ color: '#fff', textTransform: 'uppercase' }}
            >
              {CONSTS.APP_NAME}
            </Typography>
          </Button>
          <Box sx={{ flexGrow: 1 }} />
          {quizModified && (
            <Tooltip
              color="info"
              enterTouchDelay={0}
              sx={{ mx: 0.5 }}
              title="this quiz was modified"
            >
              <InfoIcon />
            </Tooltip>
          )}
          <Chip
            sx={{
              maxWidth: {
                c0: '25%',
                c1: '30%',
                c2: '35%',
                c3: '40%',
                c4: '55%',
                c5: 1,
              },
            }}
            label={
              currentQuiz && maxSteps > 0
                ? `${currentQuiz?.title} ${activeStep + 1} / ${maxSteps}`
                : currentQuiz && maxSteps === 0
                ? `${currentQuiz?.title} ${activeStep} / ${maxSteps}`
                : 'no quiz loaded'
            }
            variant="outlined"
            onDelete={currentQuiz && handleDelete}
          />
          <IconButton
            color="inherit"
            edge="end"
            size="small"
            aria-label="account of current user"
            aria-controls="menu-appbar"
            aria-haspopup="true"
            onClick={toggleProfile()}
          >
            <AccountCircle />
          </IconButton>
        </Toolbar>
      </AppBar>
      <UserProfile showProfile={showProfile} setShowProfile={setShowProfile} />
    </>
  );
};

export default Nav;
