import { useAppContext } from '../Contexts/AppContext';
import {
  MobileStepper,
  Button,
  Typography,
  Paper,
  List,
  ListItem,
  Checkbox,
  ListItemText,
  Stack,
  LinearProgress,
  ListItemButton,
} from '@mui/material';
import { useTheme } from '@mui/material/styles';
import { KeyboardArrowLeft, KeyboardArrowRight } from '@mui/icons-material/';
import { CompletedQuiz } from '.';

const Quiz = () => {
  const theme = useTheme();
  const {
    quizLoaded,
    quiz,
    setQuiz,
    quizCompleted,
    setQuizCompleted,
    activeStep,
    setActiveStep,
    maxSteps,
  } = useAppContext();

  const handleNext = () => {
    setActiveStep((prevActiveStep) => prevActiveStep + 1);
  };

  const handleBack = () => {
    setActiveStep((prevActiveStep) => prevActiveStep - 1);
  };

  const handleFinish = () => {
    setQuizCompleted(true);
  };

  const handleChange = (option) => {
    setQuiz((prev) => {
      return prev.map((q, index) =>
        index !== activeStep
          ? q
          : !q?.userAns?.length
          ? { ...q, userAns: [option] }
          : q.userAns.includes(option)
          ? { ...q, userAns: [...q.userAns.filter((opt) => opt !== option)] }
          : { ...q, userAns: [...q.userAns, option] }
      );
    });
  };

  return (
    <>
      {!quizLoaded ? (
        <LinearProgress />
      ) : quizCompleted ? (
        <CompletedQuiz />
      ) : quizLoaded && quiz?.length ? (
        <>
          <Stack sx={{ mx: 2 }}>
            <Typography variant="h6">{quiz[activeStep]?.question}</Typography>
            <Typography variant="subtitle2">
              {quiz[activeStep]?.detail}
            </Typography>
            <List>
              {quiz[activeStep].options.map((option, idx) => {
                const labelId = `checkbox-list-label-${idx}`;
                return (
                  <ListItem dense divider disableGutters key={idx}>
                    <ListItemButton onClick={() => handleChange(option)} dense>
                      <Checkbox
                        edge="start"
                        checked={
                          quiz[activeStep].userAns?.includes(option) || false
                        }
                        tabIndex={-1}
                        disableRipple
                        inputProps={{ 'aria-labelledby': labelId }}
                        name={option}
                      />
                      <ListItemText>{option}</ListItemText>
                    </ListItemButton>
                  </ListItem>
                );
              })}
            </List>
          </Stack>
          <MobileStepper
            variant="text"
            steps={maxSteps}
            position="static"
            activeStep={activeStep}
            nextButton={
              <Button
                size="small"
                onClick={
                  activeStep === maxSteps - 1 ? handleFinish : handleNext
                }
                disabled={!quiz[activeStep].userAns?.length}
              >
                {activeStep === maxSteps - 1 ? 'Finish' : 'Next'}
                {theme.direction === 'rtl' ? (
                  <KeyboardArrowLeft />
                ) : (
                  <KeyboardArrowRight />
                )}
              </Button>
            }
            backButton={
              <Button
                size="small"
                onClick={handleBack}
                disabled={activeStep === 0}
              >
                {theme.direction === 'rtl' ? (
                  <KeyboardArrowRight />
                ) : (
                  <KeyboardArrowLeft />
                )}
                Back
              </Button>
            }
          />
        </>
      ) : (
        <Paper
          square
          elevation={0}
          sx={{
            display: 'flex',
            alignItems: 'center',
            height: 50,
            pl: 2,
            bgcolor: 'background.default',
          }}
        >
          <Typography>no questions here!</Typography>
        </Paper>
      )}
    </>
  );
};

export default Quiz;
