import { useState } from 'react';
import {
  Card,
  CardContent,
  CardActionArea,
  Typography,
  Box,
} from '@mui/material';
import { useNavigate } from 'react-router-dom';
import { useAppContext } from '../Contexts/AppContext';
import { ResetQuiz } from '../Components';
import { Quiz as QuizIcon } from '@mui/icons-material';

const QuizCard = ({ title = 'title', description = 'description', id }) => {
  const navigate = useNavigate();
  const { currentQuiz, setupComplete } = useAppContext();
  const [open, setOpen] = useState(false);
  const handleClose = () => setOpen(false);
  const openQuiz = () => {
    if (currentQuiz && currentQuiz?.id !== id) setOpen(true);
    if (!currentQuiz?.id || currentQuiz?.id === id)
      setupComplete ? navigate(`/${id}/start`) : navigate(`/${id}/setup`);
  };

  return (
    <Card>
      {open && (
        <ResetQuiz
          open={open}
          setOpen={setOpen}
          handleClose={handleClose}
          id={id}
          title={title}
        />
      )}
      <CardActionArea onClick={() => openQuiz()}>
        <CardContent>
          <Box sx={{ display: 'flex' }}>
            <Typography variant="h5" component="div" sx={{ flexGrow: 1 }}>
              {title}
            </Typography>
            <QuizIcon
              color={currentQuiz?.id === id ? 'primary' : 'inherit'}
              sx={{ mx: 1, alignSelf: 'center' }}
            />
          </Box>
          <Typography variant="body2" color="text.secondary">
            {description}
          </Typography>
        </CardContent>
      </CardActionArea>
    </Card>
  );
};

export default QuizCard;
