import { useEffect } from 'react';
import { Grid, LinearProgress } from '@mui/material';
import { useAppContext } from '../Contexts/AppContext';
import { Routes, Route } from 'react-router-dom';
import { Quiz, QuizCard, QuizSetup } from '../Components';

const QuizList = () => {
  const { quizList, getQuizList } = useAppContext();

  useEffect(() => {
    (async () => await getQuizList())();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <Routes>
      <Route
        path="/"
        element={
          <Grid container spacing={1}>
            {!quizList.length && (
              <Grid item xs={12}>
                <LinearProgress />
              </Grid>
            )}
            {quizList.map((quiz) => (
              <Grid item xs={12} key={quiz.id}>
                <QuizCard
                  id={quiz.id}
                  title={quiz.title}
                  description={quiz.description}
                />
              </Grid>
            ))}
          </Grid>
        }
      />
      <Route path="/:quizid/setup" element={<QuizSetup />} />
      <Route path="/:quizid/start" element={<Quiz />} />
    </Routes>
  );
};

export default QuizList;
