import { useState, useEffect } from 'react';
import { useAppContext } from '../Contexts/AppContext';
import { useParams } from 'react-router-dom';
import {
  Typography,
  Stack,
  LinearProgress,
  Divider,
  Select,
  MenuItem,
  FormControl,
  InputLabel,
  Button,
  Tooltip,
} from '@mui/material';
import { shuffle } from '../Util';
import { Shuffle as ShuffleIcon } from '@mui/icons-material/';
import { useNavigate } from 'react-router-dom';

const QuizSetup = () => {
  const { quizid } = useParams();
  const navigate = useNavigate();
  const {
    getQuiz,
    quizLoaded,
    quiz,
    configuredQuiz,
    setConfiguredQuiz,
    setQuiz,
    setMaxSteps,
    setSetupComplete,
    setQuizModified,
  } = useAppContext();

  const [numberOfQuestions, setNumberOfQuestions] = useState('');
  const [shudShuffle, setShudShuffle] = useState(false);

  useEffect(() => {
    (async () => {
      const res = await getQuiz(quizid);
      setNumberOfQuestions(configuredQuiz.length || res.length || '');
      setShudShuffle(
        configuredQuiz.length ? configuredQuiz.length <= 1 : res.length <= 1
      );
    })();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const selectNumberOfQuestions = ({ target: { value } }) => {
    setNumberOfQuestions(value);
    const newQuiz = quiz.slice(0, value);
    setConfiguredQuiz(newQuiz);
    setShudShuffle(newQuiz.length <= 1);
  };

  const shuffleQuiz = () => {
    const shuffled = shuffle(configuredQuiz.length ? configuredQuiz : quiz);
    setConfiguredQuiz(shuffled);
  };

  const beginQuiz = () => {
    setSetupComplete(true);
    if (configuredQuiz.length) {
      setMaxSteps(configuredQuiz.length);
      setQuiz(configuredQuiz);
      setQuizModified(true);
    }

    navigate(`/${quizid}/start`);
  };

  return (
    <>
      {!quizLoaded ? (
        <LinearProgress />
      ) : (
        <Stack spacing={2} sx={{ mx: 2 }}>
          <Typography variant="h6">
            Quiz Setup
            <Divider />
          </Typography>
          <FormControl fullWidth>
            <InputLabel id="numberOfQuestionsLabel">
              {numberOfQuestions !== ''
                ? 'Number of questions'
                : 'This quiz has no questions!'}
            </InputLabel>

            <Select
              disabled={numberOfQuestions === ''}
              labelId="numberOfQuestionsLabel"
              id="numberOfQuestionsId"
              value={numberOfQuestions}
              label={
                numberOfQuestions !== ''
                  ? 'Number of questions'
                  : 'This quiz has no questions!'
              }
              onChange={selectNumberOfQuestions}
            >
              {quiz.map((_, idx) => {
                const questionNumber = idx + 1;
                return (
                  <MenuItem key={questionNumber} value={questionNumber}>
                    {questionNumber}
                  </MenuItem>
                );
              })}
            </Select>
          </FormControl>
          <Tooltip
            disableFocusListener={!shudShuffle}
            disableHoverListener={!shudShuffle}
            disableTouchListener={!shudShuffle}
            title="not much to shuffle"
          >
            <span>
              <Button
                variant="outlined"
                color="primary"
                fullWidth
                sx={{ height: 56 }}
                onClick={() => shuffleQuiz()}
                disabled={shudShuffle}
              >
                <Typography>Shuffle</Typography>
                <ShuffleIcon sx={{ m: 1 }} />
              </Button>
            </span>
          </Tooltip>

          <Button
            variant="contained"
            color="primary"
            fullWidth
            sx={{ height: 56 }}
            onClick={() => beginQuiz()}
          >
            <Typography>Begin</Typography>
          </Button>
          {/* <Link to="Quiz">Quiz</Link> */}
        </Stack>
      )}
    </>
  );
};

export default QuizSetup;
