import {
  Drawer,
  Button,
  IconButton,
  Toolbar,
  TextField,
  Divider,
  Stack,
  Typography,
} from '@mui/material';
import CloseIcon from '@mui/icons-material/Close';
import { useAuth } from '../Contexts/AuthContext';
import { useSnackbar } from '../Contexts/SnackbarContext';
import { useNavigate } from 'react-router-dom';

export const UserProfile = ({ showProfile, setShowProfile }) => {
  const navigate = useNavigate();
  const { user, signOut } = useAuth();
  const { showSnackBar } = useSnackbar();

  const handleSignOut = (e) => {
    e.preventDefault();
    signOut();
    showSnackBar('info', 'user logged out');
  };

  const clearLocalCache = (e) => {
    e.preventDefault();
    const temp = localStorage.getItem('supabase.auth.token');
    localStorage.clear();
    localStorage.setItem('supabase.auth.token', temp);
    navigate('/');
    window.location.reload(true);
    showSnackBar('info', 'local cache cleared');
  };

  return (
    <Drawer
      PaperProps={{
        sx: {
          width: 280,
        },
      }}
      anchor="right"
      open={showProfile}
      onClose={() => setShowProfile(false)}
    >
      <Toolbar disableGutters variant="dense" sx={{ mx: 1 }}>
        <Typography
          variant="subtitle2"
          component="div"
          sx={{ flexGrow: 1, textTransform: 'uppercase' }}
        >
          user profile
        </Typography>
        <IconButton
          edge="end"
          size="small"
          onClick={() => setShowProfile(false)}
        >
          <CloseIcon />
        </IconButton>
      </Toolbar>
      <Divider />
      <Stack height={1} m={2} spacing={2} component="form">
        <TextField fullWidth label="email" value={user.email} disabled />
        <Divider sx={{ flex: 1 }} />
        <Button fullWidth onClick={(e) => clearLocalCache(e)}>
          clear local quiz data
        </Button>
        <Button fullWidth onClick={(e) => handleSignOut(e)}>
          signout
        </Button>
      </Stack>
    </Drawer>
  );
};
