import { createContext, useContext } from 'react';
import { useLocalStorage, SupabaseClient } from '../Util';
const AppContext = createContext();

const AppProvider = ({ children }) => {
  const [quizListLoaded, setQuizListLoaded] = useLocalStorage(
    'quizListLoaded',
    false
  );
  const [quizList, setQuizList] = useLocalStorage('quizList', []);
  const [appDataLoading, setAppDataLoading] = useLocalStorage(
    'appDataLoading',
    true
  );
  const [quizLoaded, setQuizLoaded] = useLocalStorage('quizLoaded', false);
  const [quiz, setQuiz] = useLocalStorage('quiz', []);

  const [currentQuiz, setCurrentQuiz] = useLocalStorage('currentQuiz', null);
  const [quizCompleted, setQuizCompleted] = useLocalStorage(
    'quizCompleted',
    false
  );
  const [activeStep, setActiveStep] = useLocalStorage('activeStep', 0);
  const [maxSteps, setMaxSteps] = useLocalStorage('maxSteps', 0);
  const [configuredQuiz, setConfiguredQuiz] = useLocalStorage(
    'configuredQuiz',
    []
  );
  const [setupComplete, setSetupComplete] = useLocalStorage(
    'setupComplete',
    false
  );
  const [quizModified, setQuizModified] = useLocalStorage('activeQuiz', false);

  const getQuizList = () => {
    if (quizListLoaded) return quizList;
    return (async () => {
      const { data } = await SupabaseClient.from('quiz').select();
      setQuizList(data);
      setQuizListLoaded(true);
    })();
  };

  const getQuiz = (quizid) => {
    if (quizLoaded) return quiz;
    return (async () => {
      const { data } = await SupabaseClient.from('responses')
        .select()
        .eq('quiz', quizid);
      setQuiz(data);
      setCurrentQuiz((prev) => {
        const currentQuiz = quizList.find((quiz) => quiz.id === Number(quizid));
        return {
          ...prev,
          ...currentQuiz,
        };
      });
      setMaxSteps(data.length);
      setQuizLoaded(true);
      return data;
    })();
  };

  const resetQuiz = async () => {
    setQuizLoaded(false);
    setQuiz([]);
    setCurrentQuiz(null);
    setQuizCompleted(false);
    setActiveStep(0);
    setMaxSteps(0);
    setConfiguredQuiz([]);
    setSetupComplete(false);
    setQuizModified(false);
  };

  const value = {
    setAppDataLoading,
    quizList,
    getQuizList,
    quizLoaded,
    setQuizLoaded,
    quiz,
    setQuiz,
    getQuiz,
    quizCompleted,
    setQuizCompleted,
    activeStep,
    setActiveStep,
    maxSteps,
    setMaxSteps,
    currentQuiz,
    setCurrentQuiz,
    resetQuiz,
    configuredQuiz,
    setConfiguredQuiz,
    setupComplete,
    setSetupComplete,
    quizModified,
    setQuizModified,
  };

  return (
    <AppContext.Provider value={value}>
      {appDataLoading && children}
    </AppContext.Provider>
  );
};

const useAppContext = () => {
  const context = useContext(AppContext);
  if (!context)
    throw new Error('useAppContext must be used within AppProvider');
  return context;
};

export { AppProvider, useAppContext };
