import { useState, useEffect } from 'react';
import { Box, Typography, TextField, Stack, Divider } from '@mui/material';
import LoadingButton from '@mui/lab/LoadingButton';
import { useSnackbar } from '../Contexts/SnackbarContext';
import { useAuth } from '../Contexts/AuthContext';
import { useNavigate } from 'react-router-dom';
import { CONSTS } from '../Constants';

function AuthForm() {
  return <AuthInputs />;
}

const AuthInputs = () => {
  const initial = {
    email: '',
  };
  const [credentials, setCredentials] = useState(initial);
  const [loading, setLoading] = useState(false);
  const { showSnackBar } = useSnackbar();
  const { signIn, user } = useAuth();
  const navigate = useNavigate();

  const handleValueChanged = ({ target: { name, value } }) => {
    setCredentials({ ...credentials, [name]: value });
  };

  useEffect(() => {
    if (user) navigate('/');
  }, [user, navigate]);

  const handleSubmit = async (e) => {
    try {
      e.preventDefault();
      setLoading(true);

      if (credentials.email === '') {
        setLoading(false);
        return showSnackBar('error', 'missing inputs');
      }

      const { error } = await signIn(credentials.email);

      if (error) {
        setLoading(false);
        return showSnackBar('error', error.message);
      }

      if (!error) showSnackBar('success', `check email for your login link!`);

      navigate('/');
    } catch (error) {
      console.log(error);
    }
  };

  return (
    <Box
      p={4}
      sx={{
        display: 'flex',
        alignContent: 'center',
        justifyContent: 'center',
        minWidth: '90%',
        maxWidth: '350px',
      }}
    >
      <Stack
        key="auth-stack"
        id="auth-stack"
        spacing={2}
        direction="column"
        component="form"
        sx={{
          position: 'absolute',
          left: 0,
          right: 0,
          marginLeft: 'auto',
          marginRight: 'auto',
          width: '300px',
        }}
      >
        <Typography component={'span'} variant={'body2'}>
          {CONSTS.APP_NAME} 👋
          <Divider sx={{ paddingY: '5px' }} />
        </Typography>

        <TextField
          name="email"
          label="email"
          value={credentials.email}
          type="email"
          onChange={handleValueChanged}
          required
          autoComplete="email"
        />
        <LoadingButton
          fullWidth
          variant="outlined"
          loading={loading}
          onClick={(e) => handleSubmit(e)}
          type="submit"
        >
          Login
        </LoadingButton>
      </Stack>
    </Box>
  );
};

export default AuthForm;
