import React from 'react';
import ReactDOM from 'react-dom';
import App from './App';
import { createTheme, ThemeProvider } from '@mui/material/styles';
import { CssBaseline } from '@mui/material';
import { SnackbarProvider } from './Contexts/SnackbarContext';
import { AuthProvider } from './Contexts/AuthContext';
import { MemoryRouter } from 'react-router-dom';

const theme = createTheme({
  palette: {
    mode: 'dark',
  },
  breakpoints: {
    values: {
      xs: 0,
      sm: 600,
      md: 900,
      lg: 1200,
      xl: 1536,
      c0: 0,
      c1: 250,
      c2: 300,
      c3: 350,
      c4: 400,
      c5: 450,
      c6: 500,
    },
  },
});

ReactDOM.render(
  <React.StrictMode>
    <MemoryRouter>
      <ThemeProvider theme={theme}>
        <CssBaseline />
        <AuthProvider>
          <SnackbarProvider>
            <App />
          </SnackbarProvider>
        </AuthProvider>
      </ThemeProvider>
    </MemoryRouter>
  </React.StrictMode>,
  document.getElementById('root')
);
